#
# spec file for package cookiecutter
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


Name:           cookiecutter
Version:        1.5.0
Release:        2.1
License:        BSD-3-Clause
Summary:        A command-line utility that creates projects from project templates
Url:            https://github.com/audreyr/cookiecutter
Group:          Development/Languages/Python
Source:         https://pypi.io/packages/source/c/cookiecutter/cookiecutter-%{version}.tar.gz
# PATCH-FIX-OPENSUSE fix-python-invocation-tests.diff hpj@urpla.net
Patch0:         fix-python-invocation-tests.diff
# PATCH-FIX-UPSTREAM fix-caplog-tests.diff hpj@urpla.net
Patch1:         fix-caplog-tests.diff
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-binaryornot >= 0.2.0
BuildRequires:  python3-click >= 5.0
BuildRequires:  python3-future >= 0.15.2
BuildRequires:  python3-Jinja2 >= 2.7
BuildRequires:  python3-jinja2-time >= 0.1.0
BuildRequires:  python3-poyo >= 0.1.0
BuildRequires:  python3-whichcraft >= 0.4.0
BuildRequires:  git
# Testing requirements
BuildRequires:  python3-chardet >= 2.0.0
BuildRequires:  python3-freezegun
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-mock
BuildRequires:  python3-pytest-capturelog
Requires:       python3-binaryornot >= 0.2.0
Requires:       python3-click >= 5.0
Requires:       python3-future >= 0.15.2
Requires:       python3-Jinja2 >= 2.7
Requires:       python3-jinja2-time >= 0.1.0
Requires:       python3-poyo >= 0.1.0
Requires:       python3-whichcraft >= 0.4.0
Requires:       git
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
A command-line utility that creates projects from **cookiecutters** (project
templates), e.g. creating a Python package project from a Python package
project template.

* Cross-platform: Windows, Mac, and Linux are officially supported.

* Works with Python 2.7, 3.3, 3.4, 3.5, and PyPy. *(But you don't have to
* know/write Python
  code to use Cookiecutter.)*

* Project templates can be in any programming language or markup format:
  Python, JavaScript, Ruby, CoffeeScript, RST, Markdown, CSS, HTML, you name
it. You can use multiple languages in the same project template.

* Simple command line usage:

	# Create project from the cookiecutter-pypackage.git repo template
	# You'll be prompted to enter values.  Then it'll create your Python
	# package in the current working directory, based on those values.
	$ cookiecutter https://github.com/audreyr/cookiecutter-pypackage
	# For the sake of brevity, repos on GitHub can just use the 'gh' prefix
	$ cookiecutter gh:audreyr/cookiecutter-pypackage

* Use it at the command line with a local template:

	# Create project in the current working directory, from the local
	# cookiecutter-pypackage/ template
	$ cookiecutter cookiecutter-pypackage/

%prep
%setup -q -n cookiecutter-%{version}
%patch0 -p1
%patch1 -p1
sed -i "s/cookiecutter =/cookiecutter-%{py3_ver} =/" setup.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/cookiecutter
ln -sf %{_sysconfdir}/alternatives/cookiecutter %{buildroot}%{_bindir}/cookiecutter

%check
export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
PYTHONPATH=%{buildroot}%{python3_sitelib} py.test

%pre
[ -h %{_bindir}/cookiecutter ] || rm -f %{_bindir}/cookiecutter

%post
update-alternatives --install %{_bindir}/cookiecutter cookiecutter %{_bindir}/cookiecutter-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove cookiecutter %{_bindir}/cookiecutter-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc AUTHORS.rst LICENSE README.rst
%ghost %{_sysconfdir}/alternatives/cookiecutter
%{_bindir}/cookiecutter
%{_bindir}/cookiecutter-%{py3_ver}
%{python3_sitelib}/*

%changelog
* Fri Feb  3 2017 hpj@urpla.net
- version 1.5.0: initial build
